Asynchronous version of the socket.io client. This module contains the async
crate::asynchronous::Client as well as a builder
(crate::asynchronous::ClientBuilder) that allows for configuring a client.
Structs
- Client
- A socket which handles communication with the server. It’s initialized with
a specific address as well as an optional namespace to connect to. If
Noneis given the client will connect to the default namespace"/". - Client
Builder - A builder class for a
socket.iosocket. This handles setting up the client and configuring the callback, the namespace and metadata of the socket. If no namespace is specified, the default namespace/is taken. Theconnectmethod acts thebuildmethod and returns a connectedClient.